package com.zy.bms.controller.pc;

import com.zy.bms.common.ServerResponse;
import com.zy.bms.common.io.pc.ItemIO;
import com.zy.bms.model.Item;
import com.zy.bms.service.IItemService;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * <p>
 * 项目表 前端控制器
 * </p>
 *
 * @author chenyi
 * @since 2021-05-19
 */
@RestController
@RequestMapping("/builder/item")
public class ItemController {

    @Resource
    private IItemService itemService;

    /**
     * 分页查询所有项目
     */
    @PostMapping("listPage.do")
    public ServerResponse listPage(ItemIO io) {
        return ServerResponse.createBySuccess(itemService.listPage(io));
    }

    /**
     * 添加项目
     */
    @PostMapping("save.do")
    public ServerResponse save(Item item) {
        if (itemService.checkRepeat(item.getCode())) return ServerResponse.createByWarning("添加失败:项目编号重复");
        return ServerResponse.createBySuccess(itemService.save(item));
    }

    /**
     * 禁用项目
     */
    @PostMapping("forbidden.do")
    public ServerResponse forbidden(Integer id) {
        itemService.updateStatus(id, 0);
        return ServerResponse.createBySuccess();
    }

    /**
     * 启用项目
     */
    @PostMapping("permit.do")
    public ServerResponse permit(Integer id) {
        itemService.updateStatus(id, 1);
        return ServerResponse.createBySuccess();
    }

    /**
     * 更新项目信息
     */
    @PostMapping("update.do")
    public ServerResponse update(Item item) {
        itemService.updateById(item);
        return ServerResponse.createBySuccess();
    }
}
